$global:output_success = @()
$global:output_failed = @()

function CheckSingleServiceStatus {
    param (
        [Parameter(Mandatory=$true)]
        [String]$ServiceName
    )

    $service = Get-Service -Name $ServiceName -ErrorAction SilentlyContinue

    if ($service -eq $null) {
        $global:output_failed += "Service '$ServiceName' does not exist."
    } elseif ($service.Status -ne 'Running') {
        $global:output_failed += "Service '$ServiceName' is not running. Current status: $($service.Status)."
    } else {
        $global:output_success += "Service '$ServiceName' is running."
    }
}

function Get-WindowsServices {
    param (
        [String]$FilterString
    )

    $services = Get-Service

    if ($FilterString) {
        $filteredServices = $services | Where-Object { $_.Name -like "*$FilterString*" }
    } else {
        $filteredServices = $services
    }

    return $filteredServices
}

foreach ($argument in $args) {
	
	$services = Get-WindowsServices -FilterString $argument
	
	foreach($service in $services)
	{
		CheckSingleServiceStatus $service.Name
	}
}

# if output_failed is empty, check was a success
if($output_failed.Count -eq 0) {
	$joinedOutput = $output_success -join "`n"
	Write-Host "OK: All services running as expected`r`n$joinedOutput"
	Exit 0
}

# output_failed not empty, fail check and output result
$joinedOutput_failed = $output_failed -join "`n"
$joinedOutput_success = $output_success -join "`n"
Write-Host "CRITICAL: Some (or all) services failed`r`n$joinedOutput_failed`r`n$joinedOutput_success"
Exit 2


